aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-dcerpc-nt.c
diff options
context:
space:
mode:
authorPascal Quantin <pascal.quantin@gmail.com>2013-09-22 15:50:55 +0000
committerPascal Quantin <pascal.quantin@gmail.com>2013-09-22 15:50:55 +0000
commita0c53ffaa1bb46d8c9db2ec739401aa411c9790e (patch)
tree56a11c9e0910032ad43476462dd2c95ed65e5cc1 /epan/dissectors/packet-dcerpc-nt.c
parentc4a608a94071f4a23eaf16fd3ab9545e26309f76 (diff)
emem -> wmem conversion:
- ep_tvb_get_bits() -> wmem_packet_tvb_get_bits() - tvb_g_memdup()/ep_tvb_memdup() -> tvb_memdup() - tvb_fake_unicode()/tvb_get_ephemeral_faked_unicode() -> tvb_get_faked_unicode() - tvb_get_g_string()/tvb_get_ephemeral_string()/tvb_get_seasonal_string() -> tvb_get_string() - tvb_get_g_unicode_string()/tvb_get_ephemeral_unicode_string() -> tvb_get_unicode_string() - tvb_get_ephemeral_string_enc() -> tvb_get_string_enc() - update docs accordingly svn path=/trunk/; revision=52172
Diffstat (limited to 'epan/dissectors/packet-dcerpc-nt.c')
-rw-r--r--epan/dissectors/packet-dcerpc-nt.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/epan/dissectors/packet-dcerpc-nt.c b/epan/dissectors/packet-dcerpc-nt.c
index 72f2902a49..65b9ba6b7f 100644
--- a/epan/dissectors/packet-dcerpc-nt.c
+++ b/epan/dissectors/packet-dcerpc-nt.c
@@ -129,8 +129,8 @@ dissect_null_term_string(tvbuff_t *tvb, int offset,
}
len = tmp_offset - offset;
- /* tvb_get_ephemeral_string didn't want the length with the 0*/
- s = tvb_get_ephemeral_string(tvb, offset, len);
+ /* tvb_get_string didn't want the length with the 0*/
+ s = tvb_get_string(wmem_packet_scope(), tvb, offset, len);
proto_tree_add_string(tree, hf_index, tvb, offset, len + 1, s);
return tmp_offset;
@@ -165,8 +165,8 @@ dissect_null_term_wstring(tvbuff_t *tvb, int offset,
}
len = tmp_offset - offset;
- /* tvb_get_ephemeral_string didn't want the length with the 0*/
- s = tvb_get_g_unicode_string(tvb, offset, len, ENC_LITTLE_ENDIAN);
+ /* tvb_get_string didn't want the length with the 0*/
+ s = tvb_get_unicode_string(NULL, tvb, offset, len, ENC_LITTLE_ENDIAN);
proto_tree_add_string(tree, hf_index, tvb, offset, len, s);
g_free(s);
@@ -1285,7 +1285,7 @@ void cb_wstr_postprocess(packet_info *pinfo, proto_tree *tree _U_,
* some way we can get that string, rather than duplicating the
* efforts of that routine?
*/
- s = tvb_get_ephemeral_unicode_string(
+ s = tvb_get_unicode_string(wmem_packet_scope(),
tvb, start_offset + 12, end_offset - start_offset - 12,
ENC_LITTLE_ENDIAN);
@@ -1348,7 +1348,7 @@ void cb_str_postprocess(packet_info *pinfo, proto_tree *tree _U_,
* some way we can get that string, rather than duplicating the
* efforts of that routine?
*/
- s = tvb_get_ephemeral_string(
+ s = tvb_get_string(wmem_packet_scope(),
tvb, start_offset + 12, (end_offset - start_offset - 12) );
/* Append string to COL_INFO */